Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3)

Unified Diff: Source/modules/presentation/PresentationController.h

Issue 1026253002: Rename FrameDestructionObserver to LocalFrameLifecycleObserver. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: rebased Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/modules/plugins/DOMPlugin.cpp ('k') | Source/modules/presentation/PresentationController.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/modules/presentation/PresentationController.h
diff --git a/Source/modules/presentation/PresentationController.h b/Source/modules/presentation/PresentationController.h
index ad2aae3386e3239ccdf4e660fdaad53430e39970..38c1cf6bdee79fb4a0b8f48dc5b2e41ce1dffd9c 100644
--- a/Source/modules/presentation/PresentationController.h
+++ b/Source/modules/presentation/PresentationController.h
@@ -5,7 +5,7 @@
#ifndef PresentationController_h
#define PresentationController_h
-#include "core/frame/FrameDestructionObserver.h"
+#include "core/frame/LocalFrameLifecycleObserver.h"
#include "modules/presentation/Presentation.h"
#include "platform/Supplementable.h"
#include "platform/heap/Handle.h"
@@ -22,7 +22,7 @@ class WebPresentationSessionClient;
class PresentationController final
: public NoBaseWillBeGarbageCollectedFinalized<PresentationController>
, public WillBeHeapSupplement<LocalFrame>
- , public FrameDestructionObserver
+ , public LocalFrameLifecycleObserver
, public WebPresentationController {
WILL_BE_USING_GARBAGE_COLLECTED_MIXIN(PresentationController);
WTF_MAKE_NONCOPYABLE(PresentationController);
@@ -63,7 +63,7 @@ public:
private:
PresentationController(LocalFrame&, WebPresentationClient*);
// Implementation of FrameDestructionObserver.
virtual void willDetachFrameHost() override;
WebPresentationClient* m_client;
« no previous file with comments | « Source/modules/plugins/DOMPlugin.cpp ('k') | Source/modules/presentation/PresentationController.cpp » ('j') | no next file with comments »
@@ -63,7 +63,7 @@ public:
private:
PresentationController(LocalFrame&, WebPresentationClient*);
- // Implementation of FrameDestructionObserver.
+ // Implementation of LocalFrameLifecycleObserver.
virtual void willDetachFrameHost() override;
WebPresentationClient* m_client;

Powered by Google App Engine
This is Rietveld 408576698